@@ -468,7 +468,7 @@ class HardwareIOTypeForm(forms.Form):
 from django.forms.models import inlineformset_factory,BaseForm
 from data.models.models import HardwareStats,DataTransformer,DataTransformerConstants,HardwareDataTransformer,HardwareStatsDataTransformer
 
-DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, extra=1)
+DataTransformerInlineFormset = inlineformset_factory(DataTransformer, fk_name='data_transformer_child', extra=1)
 DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1)
 HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1)
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1)
