@@ -300,12 +300,14 @@ class HardwareStats(models.Model):
 
 class DataTransformer(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    accessory = place = models.OneToOneField(
+    accessory = models.OneToOneField(
         Accessory,
-        on_delete=models.CASCADE
+        on_delete=models.CASCADE,
+        blank = False,
+        null=False
     )
-    data_transformer_parent = models.ForeignKey('self', on_delete=models.CASCADE, blank=True, null=True, default=None)
-    data_transformer_child = models.ForeignKey('self', on_delete=models.CASCADE, blank=True, null=True, default=None)
+    data_transformer_parent = models.ForeignKey('self', related_name='data_transformer_parent',on_delete=models.CASCADE, blank=True, null=True, default=None)
+    data_transformer_child = models.ForeignKey('self', related_name='data_transformer_child',on_delete=models.DO_NOTHING, blank=True, null=True, default=None)
 
     def save(self, *args, **kwargs):
         if not self.created_at:
